bs.gene() generates the value of k-th basis function. (The wavelet basis options return the full table)
Usage
bs.gene(type, k, point = 200, c = 10, or = 4, ops = "auto")
Value
A data frame which contains the value of k-th basis function
Arguments
type
type indicates which type of basis is used. There are 31 types in this package
k
k-th basis function
point
the number of values got from k-th basis function
c
c only used in Cspli which indicates the total number of knots to generate, the default is 10, c should not be less than k.(for splines, the true
number of basis is c-2+or)
or
indicates the order of spline and only used in Cspli type, default is 4 which indicates cubic spline
ops
ops indicates the function uses existing table or theoretical way to generate, the default option is "auto"
References
[3] Chen, Xiaohong. “Large Sample Sieve Estimation of Semi-Nonparametric Models.” Handbook of Econometrics, 6(B): 5549–5632,2007.