fix.pacf.test() generates a test of lags for AR Approximations.
fix.pacf.test(ts, c, type, or = 4, lag = 3, b = 8, B.s = 1000, m = 0)It returns a list contains p value for each lag
ts is the data set which is a time series data typically
c indicates the number of basis used to estimate (For wavelet, the number of basis is 2^c. If Cspli is chosen, the real number of basis is c-2+or)
type indicates which type of basis is used. There are 31 types in this package
or indicates the order of spline and only used in Cspli type, default is 4 which indicates cubic spline
lag determine the lag of AR Approximations.The default is 3
the largest lag for auto-regressive model, the default value is 8, this parameter must be larger than lag
the number of statistics used in multiplier bootstrap, the default value is 1000
the number of window size used in multiplier bootstrap, the default value is 0 which uses the minimum volatility method to determine the number