sie.auto.fit() estimates the coefficients of AR model by sieve methods with 2 cross validation methods and elbow method.
sie.auto.fit(ts, type, or = 4, method = "LOOCV", m = 500, threshold = 0)A list contains 4 objects, the first is estimates for coefficients in AR model, the second is cross validation table, the third is estimates for each basis used in OLS and the last is optimal parameters
ts is the data set which is a time series data typically
type indicates which type of basis is used. There are 31 types in this package
indicates the order of spline and only used in Cspli type, default is 4 which indicates cubic spline
method indicates which method used to choose optimal parameters, 3 methods in this package can be used
m indicates the number of points of coefficients to estimate
threshold determines the bound for Elbow method